@@ -1,8 +1,13 @@
 # -*- coding: utf-8 -*-
 
-from simmate.utilities import get_doc_from_readme
+"""
+ASE Transformations
+--------------------
 
-__doc__ = get_doc_from_readme(__file__)
+All transformations in this module are originally from the 
+[ASE](https://wiki.fysik.dtu.dk/ase/) package. These classes simply wrap ASE's
+original code so that their use matches the other Simmate transformations.
+"""
 
 from .atomic_permutation import AtomicPermutation
 from .coordinate_perturbation import CoordinatePerturbation
