@@ -3,11 +3,11 @@
 import pytest
 
 from simmate.conftest import copy_test_files
-from simmate.workflow_engine import Workflow
+from simmate.engine import Workflow
 from simmate.workflows.utilities import (
     get_all_workflow_names,
     get_all_workflow_types,
-    get_calculators_by_type,
+    get_apps_by_type,
     get_unique_parameters,
     get_workflow,
     get_workflow_names_by_type,
@@ -17,6 +17,7 @@ from simmate.workflows.utilities import (
 
 def test_get_workflow_types():
     assert get_all_workflow_types() == [
+        # "cluster-expansion",
         "customized",
         "diffusion",
         "dynamics",
@@ -30,10 +31,12 @@ def test_get_workflow_types():
 
 
 def test_list_of_all_workflows():
-
     assert get_all_workflow_names() == [
+        # "cluster-expansion.clease.bulk-structure",
         "customized.toolkit.user-config",
         "diffusion.vasp.neb-all-paths-mit",
+        "diffusion.vasp.neb-all-paths-warren-lab",
+        "diffusion.vasp.neb-all-paths-warren-lab-quick",
         "diffusion.vasp.neb-from-endpoints-mit",
         "diffusion.vasp.neb-from-images-mit",
         "diffusion.vasp.neb-from-images-mvl-ci",
@@ -53,9 +56,13 @@ def test_list_of_all_workflows():
         "population-analysis.vasp-bader.badelf-matproj",
         "population-analysis.vasp-bader.bader-matproj",
         "population-analysis.vasp.elf-matproj",
+        # "relaxation.vasp.cluster-high-q",
+        # "relaxation.vasp.cluster-low-q",
         "relaxation.vasp.matproj",
         "relaxation.vasp.matproj-hse",
+        "relaxation.vasp.matproj-hsesol",
         "relaxation.vasp.matproj-metal",
+        "relaxation.vasp.matproj-pbesol",
         "relaxation.vasp.matproj-scan",
         "relaxation.vasp.mit",
         "relaxation.vasp.mvl-grainboundary",
@@ -67,9 +74,13 @@ def test_list_of_all_workflows():
         "relaxation.vasp.quality03",
         "relaxation.vasp.quality04",
         "relaxation.vasp.staged",
+        # "relaxation.vasp.staged-cluster",
         "restart.toolkit.automatic",
+        # "static-energy.vasp.cluster-high-qe",
         "static-energy.vasp.matproj",
         "static-energy.vasp.matproj-hse",
+        "static-energy.vasp.matproj-hsesol",
+        "static-energy.vasp.matproj-pbesol",
         "static-energy.vasp.matproj-scan",
         "static-energy.vasp.mit",
         "static-energy.vasp.mvl-neb-endpoint",
@@ -83,19 +94,20 @@ def test_list_of_all_workflows():
     ]
 
 
-def test_list_of_calculators_by_type():
-
-    assert get_calculators_by_type("static-energy") == ["vasp"]
+def test_list_of_apps_by_type():
+    assert get_apps_by_type("static-energy") == ["vasp"]
 
     with pytest.raises(TypeError):
-        get_calculators_by_type("non-existant-type")
+        get_apps_by_type("non-existant-type")
 
 
 def test_list_of_workflows_by_type():
-
     assert get_workflow_names_by_type("static-energy") == [
+        # "static-energy.vasp.cluster-high-qe",
         "static-energy.vasp.matproj",
         "static-energy.vasp.matproj-hse",
+        "static-energy.vasp.matproj-hsesol",
+        "static-energy.vasp.matproj-pbesol",
         "static-energy.vasp.matproj-scan",
         "static-energy.vasp.mit",
         "static-energy.vasp.mvl-neb-endpoint",
@@ -107,7 +119,7 @@ def test_list_of_workflows_by_type():
     assert (
         get_workflow_names_by_type(
             "static-energy",
-            calculator_name="non-existant",
+            app_name="non-existant",
         )
         == []
     )
@@ -117,17 +129,14 @@ def test_list_of_workflows_by_type():
 
 
 def test_get_workflow():
-
-    from simmate.calculators.vasp.workflows import (
-        StaticEnergy__Vasp__Matproj as workflow,
-    )
+    from simmate.apps.vasp.workflows import StaticEnergy__Vasp__Matproj as workflow
 
     assert get_workflow("static-energy.vasp.matproj") == workflow
 
 
 # This is for the test below on custom workflows
 WORKFLOW_SCRIPT = """
-from simmate.workflow_engine import Workflow
+from simmate.engine import Workflow
 
 class Example__Python__MyFavoriteSettings(Workflow):
 
@@ -143,7 +152,6 @@ my_workflow = Example__Python__MyFavoriteSettings
 
 
 def test_get_custom_workflow(tmp_path):
-
     script_name = tmp_path / "my_script.py"
 
     with script_name.open("w") as file:
@@ -155,24 +163,30 @@ def test_get_custom_workflow(tmp_path):
 
 
 def test_get_unique_paramters():
-
     assert get_unique_parameters() == [
         "angle_tolerance",
         "best_survival_cutoff",
         "chemical_system",
+        # "cluster_diameter",
         "command",
         "composition",
         "compress_output",
         "convergence_cutoff",
+        # "convergence_limit",
         "copy_previous_directory",
+        # "current_generation",
         "diffusion_analysis_id",
         "directory",
         "directory_new",
         "directory_old",
+        "empty_ion",
+        "empty_sites",
         "fitness_field",
+        # "formula_unit",
         "input_parameters",
         "is_restart",
         "max_atoms",
+        # "max_generations",
         "max_path_length",
         "max_stoich_factor",
         "max_structures",
@@ -190,6 +204,8 @@ def test_get_unique_paramters():
         "nsteadystate",
         "nsteps",
         "percolation_mode",
+        "relax_bulk",
+        "relax_endpoints",
         "run_id",
         "search_id",
         "selector_kwargs",
@@ -197,10 +213,12 @@ def test_get_unique_paramters():
         "singleshot_sources",
         "sleep_step",
         "source",
+        # "space_group",
         "standardize_structure",
         "steadystate_source_id",
         "steadystate_sources",
         "structure",
+        # "structures_per_generation",
         "subworkflow_kwargs",
         "subworkflow_name",
         "supercell_end",
@@ -213,6 +231,7 @@ def test_get_unique_paramters():
         "vacancy_mode",
         "validator_kwargs",
         "validator_name",
+        # "variable_range",
         "workflow_base",
         "write_summary_files",
     ]
@@ -220,7 +239,6 @@ def test_get_unique_paramters():
 
 @pytest.mark.django_db
 def test_load_results_from_directories(tmp_path):
-
     copy_test_files(
         tmp_path,
         test_directory=__file__,
